Structs
- System load and task statistics.
- Provides information about memory usage, as measured in pages.
- Provides status information for a process.
Enums
- The Secure Computing state of a process.
- The state of a process.
Functions
- Returns the system load average.
- Returns memory status information for the process with the provided pid.
- Returns memory status information for the current process.
- Returns memory status information for the process with the provided pid.
- Returns memory status information for the current process.